# 1.0.0 (2025 - 05 - 13)

Initial public release.

### Features

* **QUBO:** Class representing a Quadratic Unconstrained Binary Optimization  problem.
* **Solver output classes:** Basic result objects for solvers such as `Freq`, `BasicResult`, `ResultInterface`, `PartialSolution`
* **Base classes:** Base classes for `Solver`, `Postprocessor` and `Preprocessor`.
* **Configs:** Introduce `SolverConfig`, `PreprocessorConfig`, `PostprocessorConfig`

